@@ -19,8 +19,8 @@
 #' }
 CIProp=function(){
   
-  if (!("manipulate"  %in% .packages())) {
-    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+  if (!("manipulate"  %in% installed.packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate installed\n",
                       "in order to run this function.")))
   }
   
@@ -164,4 +164,4 @@ CIProp=function(){
 })
 }
 
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "conf.level","sim.reps"))
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("conf.level","sim.reps"))
