@@ -20,8 +20,8 @@ function(form,data)  {
   #a range of values in cond
   #Input should be a data frame, orig first then cond
   
-  if (!("manipulate"  %in% .packages())) {
-    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+  if (!("manipulate"  %in% installed.packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate installed\n",
                       "in order to run this function.")))
   }
   
@@ -74,4 +74,4 @@ function(form,data)  {
   
 }
 
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "level","band","lev"))
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("level","band","lev"))
