@@ -17,8 +17,8 @@
 EmpRule <- function () 
 {
   
-  if (!("manipulate"  %in% .packages())) {
-    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+  if (!("manipulate"  %in% installed.packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate installed\n",
                       "in order to run this function.")))
   }
   
@@ -176,4 +176,4 @@ EmpRule <- function ()
 })
 }
 
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "type","showpop"))
\ No newline at end of file
+# if(getRversion() >= "2.15.1")  utils::globalVariables(c("type","showpop"))
