@@ -18,8 +18,8 @@
 #' }
 EmpRuleGC <- function(mean=0,sd=1,xlab="x") {
   
-  if (!("manipulate"  %in% .packages())) {
-    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+  if (!("manipulate"  %in% installed.packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate installed\n",
                       "in order to run this function.")))
   }
   
@@ -70,4 +70,4 @@ EmpRuleGC <- function(mean=0,sd=1,xlab="x") {
     )  #end manipulate
 }  #end EmpRuleGC
 
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "shade"))
\ No newline at end of file
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("shade"))
