@@ -19,8 +19,8 @@
 #' }
 SampDist2Means <- function(pop,max.samp.sizes=50,sim.reps=1000) {
   
-  if (!("manipulate"  %in% .packages())) {
-    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+  if (!("manipulate"  %in% installed.packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate installed\n",
                       "in order to run this function.")))
   }
   
@@ -107,4 +107,4 @@ SampDist2Means <- function(pop,max.samp.sizes=50,sim.reps=1000) {
   )
 }  #end of SampDist2Means
 
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "numvar","facvar","n1","n2"))
\ No newline at end of file
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "numvar","facvar","n1","n2"))
