@@ -18,8 +18,8 @@
 #' }
 SampDistMean <- function(pop,max.samp.size=50,sim.reps=1000) {
   
-  if (!("manipulate"  %in% .packages())) {
-    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+  if (!("manipulate"  %in% installed.packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate installed\n",
                       "in order to run this function.")))
   }
   
@@ -81,4 +81,4 @@ SampDistMean <- function(pop,max.samp.size=50,sim.reps=1000) {
   )
 }  #end of SampDistMeans
 
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "variable","curvetype"))
\ No newline at end of file
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("picker", "variable","curvetype"))
