@@ -15,8 +15,8 @@
 Skewer <- function () 
 {
   
-  if (!("manipulate"  %in% .packages())) {
-    return(cat(paste0("You must be on R Studio with package manipulate attached\n",
+  if (!("manipulate"  %in% installed.packages())) {
+    return(cat(paste0("You must be on R Studio with package manipulate installed\n",
                       "in order to run this function.")))
   }
   
@@ -69,4 +69,4 @@ Skewer <- function ()
   )#end manip
 }#end Skewer
 
-if(getRversion() >= "2.15.1")  utils::globalVariables(c("alpha","showpop"))
\ No newline at end of file
+if(getRversion() >= "2.15.1")  utils::globalVariables(c("alpha","showpop"))
